@@ -9,13 +9,16 @@ module Roadie
 
       initializer "roadie-rails.setup" do |app|
         config.roadie.asset_providers = [
-          Roadie::FilesystemProvider.new(::Rails.root.join("public").to_s),
+          Roadie::FilesystemProvider.new(::Rails.root.join("public").to_s)
         ]
 
         if app.config.respond_to?(:assets) && app.config.assets
-          if app.assets
-            config.roadie.asset_providers <<
-              AssetPipelineProvider.new(app.assets)
+          if app.assets && defined?(Propshaft::Assembly) && app.assets.is_a?(Propshaft::Assembly)
+            # Initialize AssetPropshaftProvider immediately for Propshaft 1.3.0+ compatibility
+            # The after_initialize block was not executing correctly in Propshaft 1.3.0
+            config.roadie.asset_providers << AssetPropshaftProvider.new(app.assets)
+          elsif app.assets
+            config.roadie.asset_providers << AssetPipelineProvider.new(app.assets)
           else
             app.config.assets.configure do |env|
               config.roadie.asset_providers <<
